Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
licenzy\__init__.py | (no class) | 4 | 0 | 0 | 100%
licenzy\cli.py | (no class) | 53 | 53 | 0 | 0%
licenzy\core.py | LicenseError | 0 | 0 | 0 | 100%
licenzy\core.py | LicenseManager | 57 | 23 | 0 | 60%
licenzy\core.py | (no class) | 42 | 0 | 0 | 100%
licenzy\management.py | (no class) | 48 | 41 | 0 | 15%
Total |  | 204 | 117 | 0 | 43%

No items found using the specified filter.